
<footer id="footer" class="footer has-background-black-ter">
    <nav class="container level is-mobile">
        <div class="level-item ">
            <span class="icon is-large has-text-grey-light mr-1" style="font-size: 3em;">
                <i class="mdi mdi-basket-plus"></i></span>
            <div class="has-text-grey-light">
                <p class="heading is-size-6">轻松购物</p>
                <p class="title has-text-grey-light is-size-5">品种齐全</p>
            </div>
        </div>
        <div class="level-item">
            <p class="has-text-centered has-text-grey-light">|</p>
        </div>
        <div class="level-item ">
            <span class="icon is-large has-text-grey-light mr-1" style="font-size: 3em;">
                <i class="mdi mdi-shield-car"></i>
                <!-- <i class="mdi mdi-rv-truck"></i> -->
            </span>
            <div class="has-text-grey-light">
                <p class="heading is-size-6">多仓直发</p>
                <p class="title has-text-grey-light is-size-5">极速配送</p>
            </div>
        </div>
        <div class="level-item">
            <p class="has-text-centered has-text-grey-light">|</p>
        </div>
        <div class="level-item ">
            <span class="icon is-large has-text-grey-light mr-1" style="font-size: 3em;">
                <i class="mdi mdi-ballot"></i></span>
            <div class="has-text-grey-light">
                <p class="heading is-size-6">精致服务</p>
                <p class="title has-text-grey-light is-size-5">正品行货</p>
            </div>
        </div>
        <div class="level-item">
            <p class="has-text-centered has-text-grey-light">|</p>
        </div>
        <div class="level-item ">
            <span class="icon is-large has-text-grey-light mr-1" style="font-size: 3em;">
                <i class="mdi mdi-wallet-giftcard"></i></span>
            <div class="has-text-grey-light">
                <p class="heading is-size-6">畅选无忧</p>
                <p class="title has-text-grey-light is-size-5">天天低价</p>
            </div>
        </div>
        <div class="level-item">
            <p class="has-text-centered has-text-grey-light">|</p>
        </div>
        <div class="level-item ">
            <span class="icon is-large has-text-grey-light mr-1" style="font-size: 3em;">
                <i class="mdi mdi-hand-heart"></i></span>
            <div class="has-text-grey-light">
                <p class="heading is-size-6">极速退换</p>
                <p class="title has-text-grey-light is-size-5">无忧售后</p>
            </div>
        </div>
    </nav>
    <!-- <div class="dropdown-divider has-background-grey-dark"></div> -->
    
    {% comment %}
    <div class="container">
        <div class="level is-mobile is-align-items-baseline">
            <div class="level-item is-flex-direction-column">
                {% get_flatpages '/about/' as about_pages %}
                <p class="menu-label">关于我们</p>
                <ul class="menu-list">
                    {% for page in about_pages %}
                    <li><a class="{% if page.url in request.path %} is-active {% endif %}" href="/pages{{ page.url }}">{{ page.title }}</a></li>
                    {% endfor %}
                </ul>
            </div>

            <div class="level-item is-flex-direction-column">
                {% get_flatpages '/newbie/' as newbie_pages %}
                <p class="menu-label">新手指南</p>
                <ul class="menu-list">
                    {% for page in newbie_pages %}
                    <li><a class="{% if page.url in request.path %} is-active {% endif %}" href="/pages{{ page.url }}">{{ page.title }}</a></li>
                    {% endfor %}
                </ul>
            </div>
            
            <div class="level-item is-flex-direction-column">
                {% get_flatpages '/serve/' as serve_pages %}
                <p class="menu-label">售后服务</p>
                <ul class="menu-list">
                    {% for page in serve_pages %}
                    <li><a class="{% if page.url in request.path %} is-active {% endif %}" href="/pages{{ page.url }}">{{ page.title }}</a></li>
                    {% endfor %}
                </ul>
            </div>
            <div class="level-item is-flex-direction-column">
                {% get_flatpages '/faq/' as faq_pages %}
                <p class=" menu-label">常见问题</p>
                <ul class="menu-list">
                    {% for page in faq_pages %}
                    <li><a class="{% if page.url in request.path %} is-active {% endif %}" href="/pages{{ page.url }}">{{ page.title }}</a></li>
                    {% endfor %}
                </ul>
            </div>
            <div class="level-item is-flex-direction-column">
                {% get_flatpages '/faq/' as faq_pages %}
                <p class=" menu-label">联系我们</p>
                <ul class="menu-list">
                    <li><a href="https://gitee.com/bayke/bayke-shop">源码下载</a></li>
                    <!-- {% for page in faq_pages %}
                    <li><a class="{% if page.url in request.path %} is-active {% endif %}" href="/pages{{ page.url }}">{{ page.title }}</a></li>
                    {% endfor %} -->
                </ul>
            </div>
        </div>
    </div>
    {% endcomment %}
    <div class="container">
        <div class="dropdown-divider has-background-grey-dark"></div>
        <div class="content has-text-centered has-text-grey-lighter">
            <p>Copyright 2023 by <a class="has-text-grey-lighter has-text-weight-bold" href="http://www.bayke.shop">baykeShop</a>. All rights reserved.
            </p>
            <p class="is-size-7 has-text-grey-lighter">本程序由<a class="has-text-grey"
            href="https://www.djangoproject.com/">django</a>强力驱动.

            <a class="is-size-7 has-text-grey-lighter" href="/sitemap.xml">站点地图</a>
            </p>
        </div>
    </div>
</footer>