<div class="box">
    <h1 class="is-size-5 has-text-weight-bold">文章归档</h1>
    <div class="dropdown-divider"></div>
    <aside class="menu">
        <ul class="menu-list">
            {% for date in dates %}
            <li>
                <a href="{% url 'baykearticle:archive-list' date.year date.month %}" 
                    class="{% if month == date %} is-active {% endif %}">
                    {{ date }}
                </a>
            </li>
            {% endfor %}
        </ul>
        
    </aside>
</div>