<style>
    td, th{
        vertical-align: middle;
    }
    .orderskus{
        display: flex;
        align-items: center;
    }
</style>

{% for ordersku in orderskus %}
<div class="orderskus">
    <div><img src="{{ ordersku.sku_json.img }}" width="96px"></div>
    <div class="sku">
        <p style="font-weight: bold;">{{ ordersku.sku_json.title }}</p>
        {% if ordersku.sku_json.specs %}
        <p style="color: rgb(105, 105, 105);">规格：
            {% for k, v in ordersku.sku_json.specs.items %}
            <span>{{ k }}:{{ v }}</span>
            {% endfor %}
        </p>  
        {% endif %}
        <p>{{ ordersku.sku_json.price }} x {{ ordersku.count }}</p>
    </div>
</div>
{% empty %}
-
{% endfor %}
    
