{% extends 'shop/base.html' %}

{% load bayketags shoptags %}

{% block breadcrumb %}
<div class="container my-4">
	<nav class="breadcrumb is-marginless is-small" aria-label="breadcrumbs">
		<ul>
			<li><a href="{% url 'shop:home' %}">首页</a></li>
			<li class="is-active"><a href="#" aria-current="page">{{ title }}</a></li>
		</ul>
	</nav>
</div>
{% endblock %}

{% block section %}
<section class="section1">
    <div class="container">
        {% include 'shop/filters.html' %}
        <div class="columns is-multiline is-mobile">
            {% for spu in page_obj %}
            <div class="column is-3-desktop is-6-mobile">
                {% spubox spu %}
            </div>
            {% endfor %}
        </div>
        {% pagination page_obj %}
    </div>
</section>
{% endblock %}