{% extends "admin/base_site.html" %}

{% block content %}
<form action="" method="post">
    {% csrf_token %}
    <p>评论内容：{{ obj.content }}</p>
    <p>回复：
        <textarea name="reply" id="id_reply" class="vLargeTextField" cols="40" rows="10" required></textarea>
    </p>
    <div class="submit-row">
        <input type="submit" value="保存">
    </div>
</form>
{% endblock %}