{% load i18n static %}<!DOCTYPE html>
{% get_current_language as LANGUAGE_CODE %}{% get_current_language_bidi as LANGUAGE_BIDI %}
<html lang="{{ LANGUAGE_CODE|default:"en-us" }}" dir="{{ LANGUAGE_BIDI|yesno:'rtl,ltr,auto' }}">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{% block title %}{% endblock %}</title>
    <link rel="shortcut icon" href="{% static 'img/favicon.ico' %}" type="image/x-icon">
    <link rel="stylesheet" href="{% static 'css/buefy.min.css' %}">
    <link rel="stylesheet" href="{% static 'css/materialdesignicons.min.css' %}">
    <script src="{% static 'js/vue.js' %}"></script>
    <script src="{% static 'js/buefy.min.js' %}"></script>
    <style>html,body{background-color: rgb(244, 244, 244); font-size: 14px; height: 100%;}</style>
    {% block extrastyle %}{% endblock %}
</head>
<body>
    {% block common %}{% include 'system/common.html' %}{% endblock %}
    {% block header %}
    {% include 'shop/header.html' %}
    {% endblock %}
    {% block breadcrumb %}{% endblock %}
    <div class="mb-3">
    {% block section %}{% endblock %}
    </div>
    {% block footer %}
    {% include 'system/footer.html' %}
    {% endblock %}
    {% block extravue %}{% endblock %} 
</body>
</html>