{% extends 'shop/base.html' %}

{% load shoptags %}

{% block section %}
{% include 'shop/banners.html' %}
    <section class="section1">
        {% for floor in floors %}
        <div class="container">
            <div class="is-flex is-justify-content-space-between is-align-items-center py-4">
                <h1 class="is-size-4">{{ floor.name }}</h1>
                <div class="">
                    <a href="{% url 'shop:cate-detail' floor.id %}">更多>></a>
                </div>
            </div>
            <div class="columns is-multiline is-mobile">
                <div class="column is-4-widescreen is-12-mobile">
                    <figure class="image">
                        <img src="{% if floor.figure %}{{ floor.figure.url }}{% endif %}">
                    </figure>
                </div>
                {% for spu in floor.spus %}
                <div class="column is-2-widescreen is-6-mobile">
                   {% spubox spu %}
                </div>
                {% empty %}
                暂未添加任何商品！
                {% endfor %}
            </div>

        </div>
        {% endfor %}
    </section>
{% endblock %}
    